@@ -21,13 +21,16 @@ N_ech_max = 262142
 
 T_sysam = 1e-6
 
-class Voie():
+class VoieBase():
 
     def __init__(self):
         self.nom = None
         self.calibre = None
         self.repetition = None
 
+    def tester(self):
+        return not self.nom == None
+
     def tester_compatibilite_nom(self, other):
         numero = other.calculer_numero()
         liste_noms_incompatibles = []
@@ -74,10 +77,10 @@ class Voie():
             return self.calibre in liste_calibres_sorties
 
 if __name__ == "__main__":
-    v1 = Voie()
-    v2 = Voie()
-    v3 = Voie()
-    v4 = Voie()
+    v1 = VoieBase()
+    v2 = VoieBase()
+    v3 = VoieBase()
+    v4 = VoieBase()
 
     v1.nom = "EA0"
     v2.nom = "EA5"
@@ -87,3 +90,5 @@ if __name__ == "__main__":
     print(v1.tester_necessite_multiplexage(v2))
     print(v1.tester_compatibilite_nom(v2))
     print(v1.tester_compatibilite_nom(v3))
+
+    print(v4.tester())
