@@ -65,10 +65,10 @@ class FiltreSysam(FiltreBase):
         phi = sortie_filtre.mesurer_dephasage_par_rapport_a(entree_filtre)
         return self.f_mes, G, phi
 
-    def calculer_vecteur_H_cplx(self, iste_fmin_fmax, n_points, affichage = True):
+    def calculer_vecteur_H_cplx(self, liste_fmin_fmax, n_points, affichage = True):
         self.acquerir_bode(liste_fmin_fmax, n_points, affichage)
         
-    def acquerir_bode(self, liste_fmin_fmax, n_points, affichage):
+    def acquerir_bode(self, liste_fmin_fmax, n_points, affichage = True):
         self.configurer_liste_fmin_fmax(liste_fmin_fmax)
         self.configurer_n_points(n_points)
         try:
