@@ -13,15 +13,13 @@ except:
 
 
 from sysam.sysam_1_base import Sysam1Base
-from signaux.signal_gbf import SignalGBF
-from signaux.signal_fourier import SignalFourier
-from signaux.signal_sysam import SignalSysam
+from signaux.signalll import Signal
 
 
 import base.utiles_base as utb
 
 class Sysam2Mode(Sysam1Base):
-    def __init__(self, liste_signaux, affichage):
+    def __init__(self, liste_signaux, affichage = True):
         Sysam1Base.__init__(self, liste_signaux, affichage)
         self.generer_chaine_mode()
         if self.affichage:
@@ -39,10 +37,10 @@ class Sysam2Mode(Sysam1Base):
         test_synchrone = False
         if not test_trigger and test_entree and test_sortie:
             if self.liste_entrees_simples: 
-                if self.liste_entrees_simples[0].base_de_temps.Nmin == 0:
+                if self.liste_entrees_simples[0].lire_base_de_temps().lire_iemin() == 0:
                     test_synchrone = True
             if self.liste_entrees_diffs: 
-                if self.liste_entrees_diffs[0].base_de_temps.Nmin == 0:
+                if self.liste_entrees_diffs[0].lire_base_de_temps().lire_iemin() == 0:
                     test_synchrone = True
 
         chaine_mode = ""
@@ -57,33 +55,14 @@ class Sysam2Mode(Sysam1Base):
 
 
 if __name__ == "__main__":
-
-    liste_tmin_tmax = [0, 2e-3]
-    Te = 1e-4
-
-    N = 6
-    liste_signaux = []
-    for i in range(N):
-        liste_signaux.append(SignalGBF(liste_tmin_tmax = liste_tmin_tmax, Te = Te))
-
-    liste_signaux[0].configurer_voie("SA1", repetition = True)
-    liste_signaux[1].configurer_voie("SA2", repetition = True)
+    liste_tmin_tmax_1 = [0, 1]
+    liste_tmin_tmax_2 = [0.1, 1]
+    s1 = Signal(liste_tmin_tmax =liste_tmin_tmax_2, nom_voie = "EA1")
+    s2 = Signal(liste_tmin_tmax =liste_tmin_tmax_2, nom_voie = "DIFF2")
+    s3 = Signal(liste_tmin_tmax =liste_tmin_tmax_2, nom_voie = "EA3")
+    s4 = Signal(liste_tmin_tmax =liste_tmin_tmax_1, nom_voie = "SA1")
+    s5 = Signal(liste_tmin_tmax =liste_tmin_tmax_1, nom_voie = "SA2")
     
-    sysam = Sysam2Mode(liste_signaux)
-    del(sysam)
-
-    liste_signaux[2].configurer_voie("EA1", repetition = True)
-    liste_signaux[3].configurer_voie("DIFF2", repetition = True)
-
-    sysam = Sysam2Mode(liste_signaux)
-    del(sysam)
-    
-    liste_signaux[2].configurer_trigger(0.)
-    sysam = Sysam2Mode(liste_signaux)
-    del(sysam)
-
-    liste_signaux[4].configurer_voie("EA5", repetition = True)
-    sysam = Sysam2Mode(liste_signaux)
-    del(sysam)
-
+    sys = Sysam2Mode([s1, s2, s3, s4, s5])
 
+    utb.print_liste(sys.liste_entrees)
